@@ -1,7 +1,7 @@
 package Yukki;
-$Yukki::VERSION = '0.991_002'; # TRIAL
+$Yukki::VERSION = '0.991_003'; # TRIAL
 
-$Yukki::VERSION = '0.991002';use v5.24;
+$Yukki::VERSION = '0.991003';use v5.24;
 use utf8;
 use Moo;
 
@@ -19,6 +19,7 @@ use Type::Utils;
 use Types::Standard qw( Dict HashRef Str Maybe slurpy Optional );
 use Path::Tiny;
 use Types::Path::Tiny qw( Path );
+use Try::Tiny;
 
 use namespace::clean;
 
@@ -134,8 +135,11 @@ sub check_access {
     # Always grant none
     return 1 if $needs eq 'none';
 
-    my $config = $self->settings->repositories->{$repository}
-              // $self->settings->special_privileges->{$special};
+    my $config;
+    $config   = try {
+        $self->model('Root')->repository($repository)->repository_settings;
+    };
+    $config //= $self->settings->special_privileges->{$special};
 
     return '' unless $config;
 
@@ -202,7 +206,7 @@ Yukki - Yet Uh-nother wiki
 
 =head1 VERSION
 
-version 0.991_002
+version 0.991_003
 
 =head1 DESCRIPTION
 
