@@ -1,7 +1,7 @@
 package Yukki::Model::Repository;
-$Yukki::Model::Repository::VERSION = '0.991_002'; # TRIAL
+$Yukki::Model::Repository::VERSION = '0.991_003'; # TRIAL
 
-$Yukki::Model::Repository::VERSION = '0.991002';use v5.24;
+$Yukki::Model::Repository::VERSION = '0.991003';use v5.24;
 use utf8;
 use Moo;
 
@@ -14,8 +14,9 @@ use DateTime::Format::Mail;
 use Git::Repository v1.18;
 use Type::Utils;
 use Types::Path::Tiny qw( Path );
-use Types::Standard qw( Str );
+use Types::Standard qw( Bool Str );
 use Try::Tiny;
+use Yukki::Types qw( RepositoryName );
 
 use namespace::clean;
 
@@ -24,11 +25,23 @@ use namespace::clean;
 
 has name => (
     is          => 'ro',
-    isa         => Str,
+    isa         => RepositoryName,
     required    => 1,
 );
 
 
+has is_master_repository => (
+    is          => 'ro',
+    isa         => Bool,
+    required    => 1,
+    lazy        => 1,
+    default     => sub {
+        my $self = shift;
+        defined $self->app->settings->repositories->{ $self->name }
+    },
+);
+
+
 has repository_settings => (
     is          => 'ro',
     isa         => class_type('Yukki::Settings::Repository'),
@@ -85,6 +98,12 @@ sub _build_git {
 }
 
 
+sub repository_exists {
+    my $self = shift;
+    return $self->repository_path->exists;
+}
+
+
 sub author_name { shift->app->settings->anonymous->author_name }
 
 
@@ -512,6 +531,52 @@ sub clone_repository {
     return;
 }
 
+
+sub remote_config {
+    my $self = shift;
+    return +{
+        map {
+            my ($k, $v) = split /\s+/;
+            my ($r, $n, $u) = split /[.]/, $k, 3;
+            ($n, $v);
+        } $self->git->run('config', '--get-regex', 'remote\..*\.url')
+    };
+}
+
+
+sub remote {
+    my ($self, $name) = @_;
+
+    my $config = $self->remote_config;
+    return $self->app->model('Remote', {
+        repository => $self,
+        name       => $name,
+    }) if defined $config->{ $name };
+
+    return;
+}
+
+
+sub add_remote_config {
+    my ($self, $name, $url) = @_;
+    $self->git->run('remote', $name, $url);
+    return;
+}
+
+
+sub remove_remote_config {
+    my ($self, $name) = @_;
+    $self->git->run('remote', 'remote', $name);
+    return;
+}
+
+
+sub update_remote_config {
+    my ($self, $name, $url) = @_;
+    $self->git->run('remote', 'set-url', $name, $url);
+    return;
+}
+
 1;
 
 __END__
@@ -526,7 +591,7 @@ Yukki::Model::Repository - model for accessing objects in a git repository
 
 =head1 VERSION
 
-version 0.991_002
+version 0.991_003
 
 =head1 SYNOPSIS
 
@@ -551,6 +616,10 @@ L<Yukki::Model>
 This is the name of the repository. This is used to lookup the configuration for
 the repository from the F<yukki.conf>.
 
+=head2 is_master_repository
+
+This is a flag that is set to true if the configuration for this repository is stored in the mater yukki configuration file. It will be set to false if it is one of the configuration files stored under C<repo_path> defined in the master configuration.
+
 =head2 repository_settings
 
 These are the settings telling this model where to find the git repository and
@@ -568,6 +637,10 @@ This is a L<Git::Repository> object which helps us do the real work.
 
 =head1 METHODS
 
+=head2 repository_exists
+
+Checks to see if the git repository is present at all.
+
 =head2 author_name
 
 This is the author name to use when making changes to the repository.
@@ -757,6 +830,41 @@ Run on an empty repository to create an empty one.
 
 Given a remote repository URI to clone from in C<$origin>, initialize the local repository from a clone of the remote one.
 
+=head2 remote_config
+
+    my $remotes = $self->remote_config;
+    say "Origin URL: $remotes->{origin}";
+
+Returns a hash contianing all the configured remotes for the repository.
+
+=head2 remote
+
+    my $remote = $repository->remote($origin);
+
+This is a safer shortcut for:
+
+    my $remote = $app->model('Remote', { repository => $repository, name => $origin });
+
+It returns a L<Yukki::Model::Remote> or C<undef> if it does not exists.
+
+=head2 add_remote_config
+
+    $repository->add_remote_config($origin => $url);
+
+Configures a new remote repository.
+
+=head2 remove_remote_config
+
+    $respository->remove_remote_config($origin);
+
+Deletes a remote repository from the configuration.
+
+=head2 update_remote_config
+
+    $repository->update_remote_config($origin, $url);
+
+Updates the URL associated with a remote configuration.
+
 =head1 AUTHOR
 
 Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
