@@ -1,13 +1,14 @@
 package Yukki::Types;
-$Yukki::Types::VERSION = '0.991_002'; # TRIAL
+$Yukki::Types::VERSION = '0.991_003'; # TRIAL
 
-$Yukki::Types::VERSION = '0.991002';use v5.24;
+$Yukki::Types::VERSION = '0.991003';use v5.24;
 use utf8;
 
 use Type::Library -base, -declare => qw(
     LoginName AccessLevel
     NavigationLinks NavigationMenuMap
-    BaseURL BaseURLEnum BreadcrumbLinks RepositoryMap
+    BaseURL BaseURLEnum BreadcrumbLinks
+    RepositoryName RepositoryMap
     PluginConfig PluginList
     PrivilegesMap
     EmailAddress YukkiSettings
@@ -15,7 +16,7 @@ use Type::Library -base, -declare => qw(
 );
 use Type::Utils qw( declare as where message coerce enum from via class_type );
 
-use Types::Standard qw( Str Int ArrayRef Maybe HashRef Dict );
+use Types::Standard qw( Str Int ArrayRef Maybe Map HashRef Dict );
 use Types::URI qw( Uri );
 
 use Email::Address;
@@ -70,9 +71,15 @@ declare BreadcrumbLinks,
     ];
 
 
+declare RepositoryName,
+    as Str,
+    where { /^[a-zA-Z0-9_.-]{3,50}$/ },
+    message { "repository name $_ must only contain letters, numbers, and periods" };
+
+
 my $Repository = class_type 'Yukki::Settings::Repository';
 declare RepositoryMap,
-    as HashRef[$Repository];
+    as Map[RepositoryName, $Repository];
 
 coerce RepositoryMap,
     from HashRef,
@@ -154,7 +161,7 @@ Yukki::Types - standard types for use in Yukki
 
 =head1 VERSION
 
-version 0.991_002
+version 0.991_003
 
 =head1 SYNOPSIS
 
@@ -208,6 +215,10 @@ This is an array of hashes formatted like:
       href  => '/link/to/somewhere',
   }
 
+=head2 RepositoryName
+
+This limits repository names to a limited subset of ASCII.
+
 =head2 RepositoryMap
 
 This is a hash of L<Yukki::Settings::Repository> objects.
