@@ -1,7 +1,7 @@
 package Yukki::Web::Plugin::Spreadsheet;
-$Yukki::Web::Plugin::Spreadsheet::VERSION = '0.991_002'; # TRIAL
+$Yukki::Web::Plugin::Spreadsheet::VERSION = '0.991_003'; # TRIAL
 
-$Yukki::Web::Plugin::Spreadsheet::VERSION = '0.991002';use v5.24;
+$Yukki::Web::Plugin::Spreadsheet::VERSION = '0.991003';use v5.24;
 use utf8;
 use Moo;
 
@@ -131,7 +131,6 @@ sub spreadsheet_eval {
     my ($self, $params) = @_;
 
     my $ctx         = $params->{context};
-    my $plugin_name = $params->{plugin_name};
     my $file        = $params->{file};
     my $arg         = $params->{arg};
 
@@ -173,7 +172,7 @@ sub spreadsheet_eval {
         $value  = $raw->{cellerrors}{ $new_cell };
     }
     else {
-        $attrs .= qq[ title="$arg" class="spreadsheet-cell error" ];
+        $attrs .= qq[ title="$arg" class="spreadsheet-cell"];
         $value = $raw->{datavalues}{ $new_cell };
     }
 
@@ -201,7 +200,7 @@ Yukki::Web::Plugin::Spreadsheet - add spreadsheet functionality to wiki pages
 
 =head1 VERSION
 
-version 0.991_002
+version 0.991_003
 
 =head1 SYNOPSIS
 
