@@ -1,7 +1,7 @@
 package Yukki::Web::Router;
-$Yukki::Web::Router::VERSION = '0.991_002'; # TRIAL
+$Yukki::Web::Router::VERSION = '0.991_003'; # TRIAL
 
-$Yukki::Web::Router::VERSION = '0.991002';use v5.24;
+$Yukki::Web::Router::VERSION = '0.991003';use v5.24;
 use utf8;
 use Moo;
 
@@ -151,6 +151,34 @@ sub BUILD {
         ],
         target => $self->controller('Admin::User'),
     ));
+
+    $self->add_route('admin/repository/:action' => (
+        defaults => {
+            action  => 'list',
+            special => 'admin_repository',
+        },
+        validations => {
+            action => qr/^(?:add|list)$/,
+        },
+        acl => [
+            [ read => { action => [ qw( list ) ] } ],
+            [ write => { action => [ qw( add ) ] } ],
+        ],
+        target => $self->controller('Admin::Repository'),
+    ));
+
+    $self->add_route('admin/repository/:action/:repository' => (
+        defaults => {
+            special => 'admin_repository',
+        },
+        validations => {
+            action => qr/^(?:initialize|remove|kill)$/,
+        },
+        acl => [
+            [ write => { action => [ qw( initialize remove kill ) ] } ],
+        ],
+        target => $self->controller('Admin::Repository'),
+    ));
 }
 
 1;
@@ -167,7 +195,7 @@ Yukki::Web::Router - send requests to the correct controllers, yo
 
 =head1 VERSION
 
-version 0.991_002
+version 0.991_003
 
 =head1 DESCRIPTION
 
