@@ -1,7 +1,7 @@
 package Yukki::Web::Settings;
-$Yukki::Web::Settings::VERSION = '0.991_002'; # TRIAL
+$Yukki::Web::Settings::VERSION = '0.991_003'; # TRIAL
 
-$Yukki::Web::Settings::VERSION = '0.991002';use v5.24;
+$Yukki::Web::Settings::VERSION = '0.991003';use v5.24;
 use utf8;
 use Moo;
 
@@ -93,6 +93,7 @@ has menu_names => (
         user
         page
         page_bottom
+        admin
     ) ] },
 );
 
@@ -156,7 +157,7 @@ Yukki::Web::Settings - provides structure and validation to web settings in yukk
 
 =head1 VERSION
 
-version 0.991_002
+version 0.991_003
 
 =head1 DESCRIPTION
 
@@ -212,6 +213,7 @@ In case your templates have custom menus on them, you may need to set this. The
       - user
       - page
       - page_bottom
+      - admin
 
 This will insure that those menus are empty when they should be empty.
 
