@@ -1,10 +1,11 @@
 package Yukki::Web::View;
-$Yukki::Web::View::VERSION = '0.991_002'; # TRIAL
+$Yukki::Web::View::VERSION = '0.991_003'; # TRIAL
 
-$Yukki::Web::View::VERSION = '0.991002';use v5.24;
+$Yukki::Web::View::VERSION = '0.991003';use v5.24;
 use utf8;
 use Moo;
 
+use Encode qw( encode );
 use Type::Params qw( validate );
 use Scalar::Util qw( blessed reftype );
 use Spreadsheet::Engine;
@@ -12,7 +13,8 @@ use Template::Pure;
 use Text::MultiMarkdown;
 use Try::Tiny;
 use Type::Utils;
-use Types::Standard qw( Dict Str ArrayRef HashRef slurpy );
+use Types::Standard qw( Bool Dict Str ArrayRef HashRef Optional slurpy );
+use Types::URI qw( Uri );
 
 use namespace::clean;
 
@@ -98,10 +100,11 @@ sub _build_links_template {
     $self->prepare_template(
         template   => 'links.html',
         directives => [
-            '.links' => {
+            '.links li' => {
                 'link<-links' => [
-                    'a'      => 'link.label',
-                    'a@href' => 'link.href',
+                    'a'       => 'link.label',
+                    'a@href'  => 'link.href',
+                    'a@class' => 'link.class',
                 ],
             },
         ],
@@ -109,6 +112,29 @@ sub _build_links_template {
 }
 
 
+has confirm_template => (
+    is          => 'ro',
+    isa         => class_type('Template::Pure'),
+    lazy        => 1,
+    builder     => '_build_confirm_template',
+);
+
+sub _build_confirm_template {
+    my $self = shift;
+
+    $self->prepare_template(
+        template   => 'confirm.html',
+        directives => [
+            'h1.title'                  => 'title',
+            '.question'                 => 'question | encoded_string',
+            'form@class'                => 'double_confirm',
+            '#submit'                   => 'yes_label',
+            '#cancel_confirmation@href' => 'no_link',
+        ],
+    );
+}
+
+
 sub page_template {
     my ($self, $which) = @_;
 
@@ -124,8 +150,10 @@ sub page_template {
         my $menu_name = $_;
         "#nav-$menu_name .navigation" => {
             "menu_item<-$menu_name" => [
-                'a'      => 'menu_item.label',
-                'a@href' => 'menu_item.href',
+                'a'       => 'menu_item.label',
+                'a@href'  => 'menu_item.href',
+                'a@class' => 'menu_item.class',
+                'a@id'    => 'menu_item.id',
             ],
         },
     } @{ $self->app->settings->menu_names };
@@ -170,7 +198,7 @@ sub prepare_template {
     my ($template, $directives) = @{$opt}{qw( template directives )};
 
     my $template_content =
-        $self->app->locate_dir('template_path', $template)->slurp;
+        $self->app->locate_dir('template_path', $template)->slurp_utf8;
 
     return Template::Pure->new(
         template   => $template_content,
@@ -179,6 +207,50 @@ sub prepare_template {
 }
 
 
+sub render_confirmation {
+    my ($self, $opt)
+        = validate(\@_, class_type(__PACKAGE__),
+            slurpy Dict[
+                context   => class_type('Yukki::Web::Context'),
+                title     => Str,
+                question  => Str,
+                yes_label => Str,
+                no_link   => Str|Uri,
+                double_confirm => Optional[Bool],
+            ]
+        );
+    my (
+        $ctx,
+        $title,
+        $question,
+        $yes_label,
+        $no_link,
+        $double_confirm,
+    ) = @{$opt}{qw(
+        context
+        title
+        question
+        yes_label
+        no_link
+        double_confirm
+    )};
+
+    $double_confirm = $double_confirm ? 'double-confirm' : '';
+
+    return $self->render_page(
+        template => $self->confirm_template,
+        context  => $ctx,
+        vars     => {
+            title     => $title,
+            question  => $question,
+            yes_label => $yes_label,
+            no_link   => $no_link,
+            double_confirm => $double_confirm,
+        },
+    );
+}
+
+
 sub render_page {
     my ($self, $opt)
         = validate(\@_, class_type(__PACKAGE__),
@@ -210,7 +282,7 @@ sub render_page {
     }
 
     my %menu_vars = map {
-        $_ => $self->available_menu_items($ctx, $_)
+        $_ => ($self->available_menu_items($ctx, $_) || [])
     } @{ $self->app->settings->menu_names };
 
     my @scripts = $self->app->settings->all_scripts;
@@ -264,7 +336,9 @@ sub available_menu_items {
     my @items = map {
         +{
             %$_,
-            href => $ctx->rebase_url($_->{href}),
+            id    => $_->{id},
+            class => $_->{class},
+            href  => $ctx->rebase_url($_->{href}),
         },
     } grep {
         my $url = $_->{href}; $url =~ s{\?.*$}{};
@@ -274,8 +348,8 @@ sub available_menu_items {
         my $access_level_needed = $match->access_level;
         $self->check_access(
             user       => $ctx->session->{user},
-            repository => $match->mapping->{repository} // '-',
-            special    => $match->mapping->{special} // '-',
+            repository => ($match->mapping->{repository} // '-'),
+            special    => ($match->mapping->{special} // '-'),
             needs      => $access_level_needed,
         );
     } $ctx->response->navigation_menu($name);
@@ -301,6 +375,7 @@ sub render_links {
                 +{
                     label => $_->{label},
                     href  => $ctx->rebase_url($_->{href}),
+                    class => $_->{class} // '',
                 }
             } @$links ],
         },
@@ -325,7 +400,7 @@ sub render {
         view => $self,
     );
 
-    return $template->render($vars);
+    return encode('UTF-8', $template->render($vars));
 }
 
 1;
@@ -342,7 +417,7 @@ Yukki::Web::View - base class for Yukki::Web views
 
 =head1 VERSION
 
-version 0.991_002
+version 0.991_003
 
 =head1 DESCRIPTION
 
@@ -369,6 +444,10 @@ This is the template used to render info, warning, and error messages to the pag
 
 This is the template object used to render links.
 
+=head2 confirm_template
+
+The template used by L</render_confirmation>.
+
 =head1 METHODS
 
 =head2 page_template
@@ -390,6 +469,17 @@ The C<template> is the name of the template file to use.
 
 The C<directives> are the L<Template::Pure> directives to apply data given at render time to modify the template to create the output.
 
+=head2 render_confirmation
+
+    my $document = $self->render_confirmation({
+        context   => $ctx,
+        question  => 'What are you confirming?',
+        yes_label => 'Do The Thing',
+        no_link   => 'go/back',
+    });
+
+The standard Yukki confirmation screen.
+
 =head2 render_page
 
   my $document = $self->render_page({
