@@ -1,7 +1,7 @@
 package Yukki::Web::View::Page;
-$Yukki::Web::View::Page::VERSION = '0.991_002'; # TRIAL
+$Yukki::Web::View::Page::VERSION = '0.991_003'; # TRIAL
 
-$Yukki::Web::View::Page::VERSION = '0.991002';use v5.24;
+$Yukki::Web::View::Page::VERSION = '0.991003';use v5.24;
 use utf8;
 use Moo;
 
@@ -11,6 +11,8 @@ use namespace::clean;
 
 extends 'Yukki::Web::View';
 
+with 'Yukki::Web::View::Role::Navigation';
+
 # ABSTRACT: render HTML for viewing and editing wiki pages
 
 
@@ -198,19 +200,19 @@ sub blank {
 }
 
 
-sub page_navigation {
+sub standard_menu {
+    return map {
+        +{
+            action => $_,
+            href   => "page/$_/%{repository}s/%{page}s",
+        },
+    } qw( edit history rename remove );
+}
+
+
+after page_navigation => sub {
     my ($self, $response, $this_action, $vars) = @_;
 
-    for my $action (qw( edit history rename remove )) {
-        next if $action eq $this_action;
-
-        $response->add_navigation_item([ qw( page page_bottom ) ] => {
-            label => ucfirst $action,
-            href  => join('/', 'page', $action, $vars->{repository}, $vars->{page}),
-            sort  => 20,
-        });
-    }
-
     for my $view_name (keys %{ $self->app->settings->page_views }) {
         my $view_info = $self->app->settings->page_views->{$view_name};
 
@@ -226,7 +228,7 @@ sub page_navigation {
             sort  => $view_info->{sort},
         });
     }
-}
+};
 
 
 sub view {
@@ -346,13 +348,12 @@ sub remove {
     $self->page_navigation($ctx->response, 'remove', $vars)
         unless $ctx->request->path_parameters->{file};
 
-    return $self->render_page(
-        template => $self->remove_template,
-        context  => $ctx,
-        vars     => {
-            page        => $vars->{page},
-            return_link => $vars->{return_link},
-        },
+    return $self->render_confirmation(
+        context   => $ctx,
+        title     => "Remove $vars->{page}?",
+        question  => "Are you sure that you wish to remove $vars->{page} from the repository?",
+        yes_label => 'Remove Now',
+        no_link   => $vars->{return_link},
     );
 }
 
@@ -463,7 +464,7 @@ Yukki::Web::View::Page - render HTML for viewing and editing wiki pages
 
 =head1 VERSION
 
-version 0.991_002
+version 0.991_003
 
 =head1 DESCRIPTION
 
@@ -476,9 +477,13 @@ Renders wiki pages.
 Renders a page that links to the edit page for this location. This helps you
 create the links.
 
+=head2 standard_menu
+
+The standard navigation menu for pages.
+
 =head2 page_navigation
 
-Sets up the page navigation menu.
+Modifies page navigation to add custom page views to the menu.
 
 =head2 view
 
